{% extends 'blti/base.html' %}

{% load staticfiles %}

{% block mobile_css %}
    <link rel="stylesheet" type="text/css" href="{% static "blti/css/mobile.css" %}"/>
{% endblock mobile_css %}


{% block content %}
<div id="unauthorized_holder">
  <div id="unauthorized_message">
    <h2 class="ui-state-error">
        <i class="fa fa-warning"></i> <span>Unauthorized</span>
    </h2>
    <p><strong>{{ error }}</strong></p>
    <p>
      It appears that you don't have permission to access this page.  Please make sure you're authorized to view this content. If you think you should be able to view this page, please use the "Help" link to notify support of the problem.
    </p>
  </div>
</div>
{% endblock content %}
